@@ -9,7 +9,7 @@ test1 <- c("-b", "17",
            "--initial_t", "128000",
            "--power_t", "1",
            "-d", system.file("test", "train-sets", "0001.dat", package="RVowpalWabbit"),
-           "-f", system.file("test", "models", "0001.model", package="RVowpalWabbit"),
+           "-f", file.path(tempdir(), "0001.model"),
            "--cache_file", file.path(tempdir(), "0001.cache"),
            "-c",
            "--passes", "2",
